/* Time-stamp: <2006-06-05 21:34:12 jcs>
|
|  Copyright (C) 2002-2005 Jorg Schuler <jcsjcs at users sourceforge net>
|  Part of the gtkpod project.
| 
|  URL: http://www.gtkpod.org/
|  URL: http://gtkpod.sourceforge.net/
|
|  Most of the code in this file has been ported from the perl
|  script "mktunes.pl" (part of the gnupod-tools collection) written
|  by Adrian Ulrich <pab at blinkenlights.ch>.
|
|  gnupod-tools: http://www.blinkenlights.ch/cgi-bin/fm.pl?get=ipod
|
|  The code contained in this file is free software; you can redistribute
|  it and/or modify it under the terms of the GNU Lesser General Public
|  License as published by the Free Software Foundation; either version
|  2.1 of the License, or (at your option) any later version.
|
|  This file is distributed in the hope that it will be useful,
|  but WITHOUT ANY WARRANTY; without even the implied warranty of
|  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
|  Lesser General Public License for more details.
|
|  You should have received a copy of the GNU Lesser General Public
|  License along with this code; if not, write to the Free Software
|  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
|
|  iTunes and iPod are trademarks of Apple
|
|  This product is not supported/written/published by Apple!
|
|  $Id: itdb.h 1750 2007-11-01 21:57:01Z phantom_sf $
*/

#ifndef ITDB_H
#define ITDB_H

#ifdef HAVE_CONFIG_H
#  include <config.h>
#endif

#include <gpod/itdb.h>

typedef Itdb_iTunesDB iTunesDB;
typedef Itdb_Playlist Playlist;
typedef Itdb_Track Track;
typedef Itdb_Thumb Thumb;
typedef Itdb_Artwork Artwork;
typedef Itdb_IpodInfo IpodInfo;
typedef Itdb_PhotoDB PhotoDB;
typedef Itdb_PhotoAlbum PhotoAlbum;
#endif
